/**********************************************************************
Copyright (c) 2009-2010 Alexander Kerner. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 ***********************************************************************/

package net.sf.jcmdlineparser.options;

import java.util.ArrayList;
import java.util.Collection;

/**
 * 
 * {@code AbstractMultiOption} is an abstract prototype of
 * {@link AbstractOption}.
 * 
 * <p>
 * This command line option can have more than one value.
 * </p>
 * 
 * <p>
 * This class is fully thread save.
 * </p>
 * 
 * @author <a href="mailto:alex.kerner.24@googlemail.com">Alexander Kerner</a>
 * @version 2010-11-24
 * 
 */
public abstract class AbstractMultiOption<T> extends AbstractOption<T> {

	/**
	 * 
	 * Delimiter between values.
	 * 
	 */
	public final static String DELIM_PATTERN = ",";

	private volatile Collection<T> values = new ArrayList<T>();

	protected AbstractMultiOption(Class<T> returnType, char identifierShort,
			String identifierLong, String description, boolean required) {
		super(returnType, identifierShort, identifierLong, description,
				required);
	}
	
	protected AbstractMultiOption(Class<T> returnType, char identifierShort,
			String identifierLong, String description, boolean required, Collection<? extends T> values) {
		super(returnType, identifierShort, identifierLong, description,
				required);
		setValues(values);
	}

	/**
	 * 
	 * Get values.
	 * 
	 * @throws OptionNotSetException
	 *             if this {@link AbstractOption} was not provided on the
	 *             command line
	 */
	public final synchronized Collection<T> getValues() {
		if (this.isSet())
			return new ArrayList<T>(values);
		throw new OptionNotSetException("option \"" + this + "\" not set");
	}

	/**
	 * Set values.
	 * 
	 * @param values values to set
	 */
	public final synchronized void setValues(Collection<? extends T> values) {
		this.values.clear();
		this.values.addAll(values);
		this.setSet(true);
	}

}
