/**********************************************************************
Copyright (c) 2009-2010 Alexander Kerner. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 *********************************************************************/

package net.sf.jcmdlineparser.options;


/**
 * <p>
 * An {@code IntegerSingleOption} represents a command line option that has one
 * integer value.
 * </p>
 * <p>
 * Example:
 * <ul>
 * <li>
 * {@code -i 10}</li>
 * <li>
 * {@code --integer=5}</li>
 * </ul>
 * </p>
 * 
 * @author <a href="mailto:alex.kerner.24@googlemail.com">Alexander Kerner</a>
 * @version 2010-08-10
 * @see AbstractSingleOption
 * @see AbstractOption
 * 
 */
public class IntegerSingleOption extends AbstractSingleOption<Integer> {

	// lastVisit 2010-08-11

	/**
	 * TODO
	 */
	protected IntegerSingleOption(Class<Integer> returnType,
			char identifierShort, String identifierLong, String description,
			boolean required) {
		super(returnType, identifierShort, identifierLong, description,
				required);

	}

	/**
	 * TODO
	 */
	protected IntegerSingleOption(Class<Integer> returnType,
			char identifierShort, String identifierLong, String description,
			boolean required, Integer initValue) {
		super(returnType, identifierShort, identifierLong, description,
				required, initValue);

	}

	@Override
	public void parse(String string) {
		if(string == null)
			throw new NullPointerException();
		if(string.length() < 1)
			throw new NumberFormatException();
		this.setValue(Integer.parseInt(string));
	}

}
