/**********************************************************************
Copyright (c) 2009-2010 Alexander Kerner. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 *********************************************************************/

package net.sf.jcmdlineparser.strategy;

import java.util.Set;

import net.sf.jcmdlineparser.ParserException;
import net.sf.jcmdlineparser.options.AbstractOption;


/**
 * The <code>Strategy</code> interface represents a parsing strategy, meaning
 * the parsing logic. <br>
 * An implementation of <code>Strategy</code> expects the command line String to
 * have a certain format, that is known to the <code>Strategy</code>
 * implementation:
 * <p>
 * <blockquote>key1=value2 key2=value2</blockquote> would be such a simple
 * format.
 * 
 * @author <a href="mailto:alex.kerner.24@googlemail.com">Alexander Kerner</a>
 * @version 2010-08-10
 * @see AbstractOption
 * 
 * 
 */
public interface Strategy {

	// lastVisit 2010-08-11

	/**
	 * @param string
	 *            Command line arguments, that will be parsed.
	 * @param options
	 *            A list of options, for which will be parsed.
	 * @return Single <code>String</code>, that contains all remaining
	 *         arguments, that could not be recognized by this
	 *         <code>Strategy</code>
	 * @throws ParserException 
	 * 
	 * @see AbstractOption
	 */
	String parse(String string, Set<AbstractOption<?>> options)
			throws ParserException;

	/**
	 * @param string
	 *            Command line arguments, that will be parsed.
	 * @param options
	 *            A list of options, for which will be parsed.
	 * @return Array of <code>String</code>, that contains all remaining
	 *         arguments, that could not be recognized by this
	 *         <code>Strategy</code>
	 * @throws ParserExceptio
	 * 
	 * @see AbstractOption
	 */
	String[] parse(String[] string, Set<AbstractOption<?>> options)
			throws ParserException;

}
